import request from '@/utils/request'

// 查询金四-用户登记列表
export function listInvoiceallyhdj(query) {
  return request({
    url: '/invoiceall/invoiceallyhdj/list',
    method: 'get',
    params: query
  })
}

// 查询金四-用户登记详细
export function getInvoiceallyhdj(id) {
  return request({
    url: '/invoiceall/invoiceallyhdj/' + id,
    method: 'get'
  })
}

//用户登记
export function registeredMethod(registeredParams,identity) {
  return request({
    url: '/api/invoice_all/v1/registration?identity=' + identity+"&order="+registeredParams,
    method: 'post',
  })
}

//人脸识别
export function qrcodeMethod(qrcodeParams,identity) {
  return request({
    url: '/api/invoice_all/v1/qrcode?identity=' + identity+"&order="+qrcodeParams,
    method: 'post',
  })
}

// 新增金四-用户登记
export function addInvoiceallyhdj(data) {
  return request({
    url: '/invoiceall/invoiceallyhdj',
    method: 'post',
    data: data
  })
}

// 修改金四-用户登记
export function updateInvoiceallyhdj(data) {
  return request({
    url: '/invoiceall/invoiceallyhdj',
    method: 'put',
    data: data
  })
}

// 删除金四-用户登记
export function delInvoiceallyhdj(id) {
  return request({
    url: '/invoiceall/invoiceallyhdj/' + id,
    method: 'delete'
  })
}

export function encrypt(data) {
  return request({
    url: '/sandbox/encrypt',
    method: 'post',
    data: data
  })
}

export function getCompanyservice(companyid) {
  return request({
    url: '/system/companyservice/' + companyid,
    method: 'get'
  })
}
